std.block.heal.core


check-errored-suspectclj

(check-errored-suspect scan lines leftover-errors)

create-block-scanclj

(create-block-scan block lines)
(create-block-scan block lines line col)
(create-block-scan block lines line col end-col)

creates a scan window for a block.

The default arity scans the full block. The extended arities allow the caller to override the scan line range, start column, and optional end column when a smaller suspect region has already been identified.

creates a scan window for a block.

The default arity scans the full block. The extended arities allow the
caller to override the scan line range, start column, and optional end
column when a smaller suspect region has already been identified.
raw docstring

create-close-hint-scanclj

(create-close-hint-scan block lines scan interim interim-errors)

uses a later correct close delimiter to narrow the suspect scan window

uses a later correct close delimiter to narrow the suspect scan window
raw docstring

default-max-colclj


get-block-linesclj

(get-block-lines lines [start end] start-col & [end-col])

gets the block lines

gets the block lines
raw docstring

get-erroredclj

(get-errored content)

checks content for irregular blocks

checks content for irregular blocks
raw docstring

get-errored-loopclj

(get-errored-loop block lines)

runs the check block loop

runs the check block loop
raw docstring

get-errored-rawclj

(get-errored-raw lines blocks)

helper function for get-errored

helper function for get-errored
raw docstring

group-blocksclj

(group-blocks content)

groups the lines by colation sections

groups the lines by colation sections
raw docstring

group-blocks-multiclj

(group-blocks-multi entries)
(group-blocks-multi entries col)

categorises the blocks

categorises the blocks
raw docstring

group-blocks-prepclj

(group-blocks-prep content)

prepares the block entries for a file

prepares the block entries for a file
raw docstring

group-blocks-prep-entriesclj

(group-blocks-prep-entries delimiters starts)

prepares the block entries for a file

prepares the block entries for a file
raw docstring

group-blocks-singleclj

(group-blocks-single entries col)

creates a single block

creates a single block
raw docstring

group-entriesclj

(group-entries entries col)

groups entries by colation

groups entries by colation
raw docstring

group-min-colclj

(group-min-col entries prev)

gets the minimum column

gets the minimum column
raw docstring

heal-contentclj

(heal-content content)

allow multiple passes to heal the delimiter

allow multiple passes to heal the delimiter
raw docstring

heal-content-complex-editsclj

(heal-content-complex-edits info errors)

heal-content-single-passclj

(heal-content-single-pass content)

heals the content in a single pass

heals the content in a single pass
raw docstring

localize-close-hint-scanclj

(localize-close-hint-scan block lines)

runs a close-delimiter localization pass before the full structural check

runs a close-delimiter localization pass before the full structural check
raw docstring

tighter-scan?clj

(tighter-scan? scan line col end-col)

checks if the candidate scan is narrower than the current scan

checks if the candidate scan is narrower than the current scan
raw docstring

wrap-diffclj

(wrap-diff print-fn)

wraps the heal function to output the diff

wraps the heal function to output the diff
raw docstring

wrap-print-diffclj

(wrap-print-diff print-fn)

print wrapper for the heal function

print wrapper for the heal function
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries