(check-errored-suspect scan lines leftover-errors)(create-block-scan block lines)(create-block-scan block lines line col)(create-block-scan block lines line col end-col)creates a scan window for a block.
The default arity scans the full block. The extended arities allow the caller to override the scan line range, start column, and optional end column when a smaller suspect region has already been identified.
creates a scan window for a block. The default arity scans the full block. The extended arities allow the caller to override the scan line range, start column, and optional end column when a smaller suspect region has already been identified.
(create-close-hint-scan block lines scan interim interim-errors)uses a later correct close delimiter to narrow the suspect scan window
uses a later correct close delimiter to narrow the suspect scan window
(get-block-lines lines [start end] start-col & [end-col])gets the block lines
gets the block lines
(get-errored content)checks content for irregular blocks
checks content for irregular blocks
(get-errored-loop block lines)runs the check block loop
runs the check block loop
(get-errored-raw lines blocks)helper function for get-errored
helper function for get-errored
(group-blocks content)groups the lines by colation sections
groups the lines by colation sections
(group-blocks-multi entries)(group-blocks-multi entries col)categorises the blocks
categorises the blocks
(group-blocks-prep content)prepares the block entries for a file
prepares the block entries for a file
(group-blocks-prep-entries delimiters starts)prepares the block entries for a file
prepares the block entries for a file
(group-blocks-single entries col)creates a single block
creates a single block
(group-entries entries col)groups entries by colation
groups entries by colation
(group-min-col entries prev)gets the minimum column
gets the minimum column
(heal-content content)allow multiple passes to heal the delimiter
allow multiple passes to heal the delimiter
(heal-content-complex-edits info errors)(heal-content-single-pass content)heals the content in a single pass
heals the content in a single pass
(localize-close-hint-scan block lines)runs a close-delimiter localization pass before the full structural check
runs a close-delimiter localization pass before the full structural check
(tighter-scan? scan line col end-col)checks if the candidate scan is narrower than the current scan
checks if the candidate scan is narrower than the current scan
(wrap-diff print-fn)wraps the heal function to output the diff
wraps the heal function to output the diff
(wrap-print-diff print-fn)print wrapper for the heal function
print wrapper for the heal function
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |